part of 'exercise_log_bloc.dart';

@immutable
abstract class ExerciseLogState extends Equatable {
  const ExerciseLogState();

  @override
  List<Object> get props => [];
}

class ExerciseLogInitial extends ExerciseLogState {
  const ExerciseLogInitial();
}

class ExerciseLogLoading extends ExerciseLogState {
  const ExerciseLogLoading();
}

class ExerciseLogReady extends ExerciseLogState {
  const ExerciseLogReady();
}

class ExerciseLogError extends ExerciseLogState {
  final String message;
  const ExerciseLogError({required this.message});

  @override
  List<Object> get props => [message];
}
